Crate std_shims

Crate std_shims 

Modules

vec
A contiguous growable array type with heap-allocated contents, written Vec<T>.

Macros

vec
Creates a Vec containing the arguments.

Structs

BTreeMap
An ordered map based on a B-Tree.
BTreeSet
An ordered set based on a B-Tree.
Box
A pointer type that uniquely owns a heap allocation of type T.
Rc
A single-threaded reference-counting pointer. ‘Rc’ stands for ‘Reference Counted’.
String
A UTF-8–encoded, growable string.
Vec
A contiguous growable array type, written as Vec<T>, short for ‘vector’.

Traits

ToString
A trait for converting a value to a String.